@@ -6,7 +6,7 @@
 import numpy as np
 
 from six.moves import reduce
-from .testing import setup_test  # noqa
+from . import setup_test  # noqa
 
 
 class AffineError(ValueError):
@@ -238,7 +238,7 @@ def append_diag(aff, steps, starts=()):
 
 
 def dot_reduce(*args):
-    """ Apply numpy dot product function from right to left on arrays
+    r""" Apply numpy dot product function from right to left on arrays
 
     For passed arrays :math:`A, B, C, ... Z` returns :math:`A \dot B \dot C ...
     \dot Z` where "." is the numpy array dot product.
