@@ -8,7 +8,7 @@ from numbers import Integral
 from platform import processor, machine
 
 import numpy as np
-from .testing import setup_test  # noqa
+from . import setup_test  # noqa
 
 
 class CastingError(Exception):
