@@ -17,8 +17,10 @@ from os.path import dirname, abspath, join as pjoin
 
 import numpy as np
 from numpy.testing import assert_array_equal
+from numpy.testing import dec
+skipif = dec.skipif
+slow = dec.slow
 
-from numpy.testing.decorators import skipif
 # Allow failed import of nose if not now running tests
 try:
     from nose.tools import (assert_equal, assert_not_equal,
@@ -209,13 +211,3 @@ def assert_arr_dict_equal(dict1, dict2):
     for key, value1 in dict1.items():
         value2 = dict2[key]
         assert_array_equal(value1, value2)
-
-
-def setup_test():
-    """ Set numpy print options to "legacy" for new versions of numpy
-
-    If imported into a file, nosetest will run this before any doctests.
-    """
-    from distutils.version import LooseVersion
-    if LooseVersion(np.__version__) >= LooseVersion('1.14'):
-        np.set_printoptions(legacy="1.13")
