@@ -19,6 +19,8 @@ import functools
 import itertools
 import gzip
 import bz2
+import threading
+import time
 
 import numpy as np
 
@@ -45,6 +47,7 @@ from ..volumeutils import (array_from_file,
                            rec2dict,
                            _dt_min_max,
                            _write_data,
+                           _ftype4scaled_finite,
                            )
 from ..openers import Opener, BZ2File
 from ..casting import (floor_log2, type_info, OK_FLOATS, shared_range)
@@ -1245,3 +1248,50 @@ def test_array_from_file_overflow():
                  'Expected {0} bytes, got {1} bytes from {2}\n'
                  ' - could the file be damaged?'.format(
                      11390625000000000000, 0, 'object'))
+
+
+def test__ftype4scaled_finite_warningfilters():
+    # This test checks our ability to properly manage the thread-unsafe
+    # warnings filter list.
+
+    # _ftype4scaled_finite always operates on one-or-two element arrays
+    # Ensure that an overflow will happen for < float64
+    finfo = np.finfo(np.float32)
+    tst_arr = np.array((finfo.min, finfo.max), dtype=np.float32)
+
+    go = threading.Event()
+    stop = threading.Event()
+    err = []
+    class MakeTotalDestroy(threading.Thread):
+        def run(self):
+            # Restore the warnings filters when we're done testing
+            with warnings.catch_warnings():
+                go.set()
+                while not stop.is_set():
+                    warnings.filters[:] = []
+                    time.sleep(0)
+    class CheckScaling(threading.Thread):
+        def run(self):
+            go.wait()
+            # Give ourselves a few bites at the apple
+            # 200 loops through the function takes ~10ms
+            # The highest number of iterations I've seen before hitting interference
+            # is 131, with 99% under 30, so this should be reasonably reliable.
+            for i in range(200):
+                try:
+                    # Use float16 to ensure two failures and increase time in function
+                    _ftype4scaled_finite(tst_arr, 2.0, 1.0, default=np.float16)
+                except Exception as e:
+                    err.append(e)
+                    break
+            stop.set()
+
+    thread_a = CheckScaling()
+    thread_b = MakeTotalDestroy()
+    thread_a.start()
+    thread_b.start()
+    thread_a.join()
+    thread_b.join()
+
+    if err:
+        raise err[0]
